@@ -70,7 +70,7 @@ def find_calibre_file_names():
         except AttributeError:
             print >> sys.stderr, \
                 "Warning: book %s (%s) has no file associated." % (
-                elem.id.text, elem.title.text)
+                elem.id.text, elem.title.text.encode("utf-8"))
 
 
 FileItem = namedtuple('FileItem', 'id uuid title isbn files authors series series_idx')
@@ -100,15 +100,17 @@ def find_calibre_books(search=None):
                      for fmtel in elem.formats.iterchildren("format")]
         except AttributeError:
             files = []
-            print "Warning: book %s (%s) has no file associated." % (
-                elem.id.text, elem.title.text)
+            print >> sys.stderr, \
+                    "Warning: book %s (%s) has no file associated." % (
+                    elem.id.text, elem.title.text.encode("utf-8"))
         try:
             authors = [fmtel.text
                        for fmtel in elem.authors.iterchildren("author")]
         except AttributeError:
             authors = []
-            print "Warning: book %s (%s) has no author associated." % (
-                elem.id.text, elem.title.text)
+            print >> sys.stderr, \
+                    "Warning: book %s (%s) has no author associated." % (
+                    elem.id.text, elem.title.text.encode("utf-8"))
         if hasattr(elem, "series"):
             series = elem.series.text
             series_idx = elem.series.attrib["index"]
