@@ -35,7 +35,9 @@ def run():
 
     correct_count = 0
     missing_count = 0
-    for file_name in find_disk_files(root):
+    for file_name in find_disk_files(root, min_level = 2, max_level = 2,
+                                     ignored_names=["metadata.opf", "cover.jpg", "cover.png"],
+                                     ignored_extensions = ["~", ".jpg", ".gif"]):
         if not file_name in known_by_calibre:
             print file_name
             missing_count += 1
